==> cms-db_v0.7.9.tar.gz: admin/pages.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('pages');
include('locale.inc.php');
$locale = new LocalizingClass('pages');

include('../functions_url.inc.php');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('desc_pages') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
		<script src="jquery.js" type="text/javascript"></script>
		<script src="anchormenu.js" type="text/javascript"></script>
	</head>
	<body>
	<?php
	// include('mobile.inc.php');
	// Opera Mini would reload the whole page (keeping here if we need this again)
	// if (strpos(strtolower($_SERVER['HTTP_USER_AGENT']), 'opera mini') === false) {
	// } else {
	// }
	?>

<h1><?php locale('desc_pages') ?></h1>

<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="#edit" class="nonewtab"><?php locale('link_editpage') ?></a></li><li><a href="#visibility" class="nonewtab"><?php locale('link_visibility') ?></a></li><li><a href="#new" class="nonewtab"><?php locale('link_newpage') ?></a></li><li><a href="#rename" class="nonewtab"><?php locale('link_renamepage') ?></a></li><li><a href="#delete" class="nonewtab"><?php locale('link_deletepage') ?></a></li><li><a href="#sort" class="nonewtab"><?php locale('link_sortpages') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

<?php
if ($_GET['saved']) {
	echo '<p class="hint">'.sprintf(locale('desc_saved',true), $_GET['saved']).'</p>';
}
?>

<div id="edit">
<h2><?php locale('title_editpage') ?></h2>
<?php
function createPageOverview($ordner, $sub = FALSE, $secfolder = 0) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if($dirs) {
  	echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
	  $shorturl = get_short_url(substr($ordner,13).'/'.$file.'/01,Home');
      echo '<li><a href="editpage.php?file='.urlencode($shorturl).'&'.SID.'">'.htmlspecialchars($show);
      if (file_exists('../data/.autosave_'.$shorturl)) {
        echo '<img src="unpublished.png" width="16" height="16" alt="" style="vertical-align: middle; margin-left: .2em" />';
      }
	  createPageOverview($dir, TRUE, $file);
      echo '</a></li>';
    }
    echo '</ul>';
  }
  closedir($handle);
}
createPageOverview("../data/pages");
?>
</div>

<div id="visibility">
<h2><?php locale('title_visibility') ?></h2>
<?php
function createDelRestorePageOverview($ordner, $sub = FALSE, $secfolder = 0) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if($dirs) {
   	echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      $show = str_replace(".DEL","",$show);
      $pos = strpos($file, ".DEL");
      if ($pos === false) {
         if ($show != "Home") {
           echo '<li><a href="invisible.php?file='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'&'.SID.'" style="color: #3dbd17">'.htmlspecialchars($show).'</a>';
         } else {
           echo '<li><span class="inactive">'.$show.'</span>';
         }
         createDelRestorePageOverview($dir, TRUE, $file);
        echo '</li>';
      } else {
      	echo '<li><a href="visible.php?file='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'&'.SID.'" style="color: #ff0000">'.htmlspecialchars($show).'</a></li>';
      }
    }
  	echo '</ul>';
  }
  closedir($handle);
}
createDelRestorePageOverview("../data/pages");
?>
<p>
	<i>
		<?php locale('desc_visibility') ?>
	</i>
</p>
</div>

<div id="new">
<h2><?php locale('title_new') ?></h2>
<p>
	<?php locale('desc_new') ?>
</p>
<?php
function createNewPageOverview($ordner, $sub = FALSE, $secfolder = 0) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if($dirs) {
  	echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      echo '<li><a href="new.php?sec='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'&'.SID.'">'.htmlspecialchars($show).'</a>';
      createNewPageOverview($dir, TRUE, $file);
      echo '</li>';
    }
  	echo '</ul>';
  }
  closedir($handle);
}
echo '<ul class="linklist"><li><a href="new.php?sec=root&'.SID.'">root</a></li>';
createNewPageOverview("../data/pages");
echo '</ul>';
?>
</div>

<div id="rename">
<h2><?php locale('title_rename') ?></h2>
<?php
function createRenamePageOverview($ordner, $sub = FALSE, $secfolder = 0) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if($dirs) {
  	echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      if ($file != "01,Home") {
        echo '<li><form action="rename.php?'.SID.'" method="post" style="display:inline">';
        /* TODO: Maybe it is possible to rename files other than pages of the cms? (though it would require sending a special post request) */
        echo '<label for="'.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'">'.htmlspecialchars($show).'</label>&rarr;<input type="text" id="'.get_short_url(substr($ordner,13).'/'.$file.'/01,Home').'" name="name" /><input type="hidden" name="path" value="'.str_replace('"', '&quot;', $ordner).'" /><input type="hidden" name="file" value="'.str_replace('"', '&quot;', $file).'" /><input type="submit" value="'.locale('button_rename',true).'" /></form>';
      } else {
        echo '<li><span class="inactive">'.$show.'</span>';
      }
      createRenamePageOverview($dir, TRUE, $file);
      echo '</li>';
    }
    echo '</ul>';
  }
  closedir($handle);
}
createRenamePageOverview("../data/pages");
?>
</div>

<div id="delete">
<h2><?php locale('title_delete') ?></h2>
<?php
function createDeletePageOverview($ordner, $sub = FALSE, $secfolder = 0) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if($dirs) {
  	echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      if ($file != "01,Home") {
        echo '<li><a href="delete.php?file='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'&'.SID.'">'.htmlspecialchars($show).'</a>';
      } else {
        echo '<li><span class="inactive">'.$show.'</span>';
      }
      createDeletePageOverview($dir, TRUE, $file);
      echo '</li>';
    }
  	echo '</ul>';
  }
  closedir($handle);
}
createDeletePageOverview("../data/pages");
?>
</div>

<div id="sort">
<h2><?php locale('title_sort') ?></h2>
<p>
	<?php locale('desc_sort') ?>
</p>
<?php
function createSortPageOverview($ordner, $sub = FALSE, $secfolder = 0) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if($dirs) {
  	echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      echo '<li><a href="sort1.php?sec='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'">'.htmlspecialchars($show).'</a>';
      createSortPageOverview($dir, TRUE, $file);
      echo '</li>';
    }
    echo '</ul>';
  }
  closedir($handle);
}
echo '<ul class="linklist"><li><a href="sort1.php?sec=root&'.SID.'">root</a></li>';
createSortPageOverview("../data/pages");
echo '</ul>';
?>
</div>

	</body>
</html>

==> cms-db_v0.8.1.tar.gz: admin/pages.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('pages');
include('locale.inc.php');
$locale = new LocalizingClass('pages');

include('../functions_url.inc.php');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('desc_pages') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
		<script src="jquery.js" type="text/javascript"></script>
		<script src="anchormenu.js" type="text/javascript"></script>
	</head>
	<body>
	<?php
	// include('mobile.inc.php');
	// Opera Mini would reload the whole page (keeping here if we need this again)
	// if (strpos(strtolower($_SERVER['HTTP_USER_AGENT']), 'opera mini') === false) {
	// } else {
	// }
	?>

<h1><?php locale('desc_pages') ?></h1>

<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="#edit" class="nonewtab"><?php locale('link_editpage') ?></a></li><li><a href="#visibility" class="nonewtab"><?php locale('link_visibility') ?></a></li><li><a href="#new" class="nonewtab"><?php locale('link_newpage') ?></a></li><li><a href="#rename" class="nonewtab"><?php locale('link_renamepage') ?></a></li><li><a href="#delete" class="nonewtab"><?php locale('link_deletepage') ?></a></li><li><a href="#sort" class="nonewtab"><?php locale('link_sortpages') ?></a></li><li><a href="#attributes" class="nonewtab"><?php locale('link_attributes') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

<?php
if (isset($_GET['saved'])) {
	echo '<p class="hint">'.sprintf(locale('desc_saved',true), $_GET['saved']).'</p>';
}
?>

<div id="edit">
<h2><?php locale('title_editpage') ?></h2>
<?php
function createPageOverview($ordner) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if(isset($dirs)) {
    echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      $shorturl = get_short_url(substr($ordner,13).'/'.$file.'/01,Home');
      $shorturl_autosave = str_replace('/', '_', $shorturl);
      echo '<li><a href="editpage.php?file='.urlencode($shorturl).'&'.SID.csrf_protection_get_html_ret().'">'.htmlspecialchars($show);
      if (file_exists('../data/.autosave_'.$shorturl_autosave)) {
        echo '<img src="unpublished.png" width="16" height="16" alt="" style="vertical-align: middle; margin-left: .2em" />';
      }
      echo '</a>';
      createPageOverview($dir);
      echo '</li>';
    }
    echo '</ul>';
  }
  closedir($handle);
}
createPageOverview("../data/pages");
?>
</div>

<div id="visibility">
<h2><?php locale('title_visibility') ?></h2>
<?php
function createDelRestorePageOverview($ordner) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if(isset($dirs)) {
    echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      $show = str_replace(".DEL","",$show);
      $pos = strpos($file, ".DEL");
      if ($pos === false) {
        if ($show != 'Home') {
          echo '<li><a href="invisible.php?file='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'&amp;'.SID.csrf_protection_get_html_ret().'" style="color: #3dbd17">'.htmlspecialchars($show).'</a>';
        } else {
          echo '<li><span class="inactive">'.$show.'</span>';
        }
        createDelRestorePageOverview($dir);
        echo '</li>';
      } else {
        echo '<li><a href="visible.php?file='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'&amp;'.SID.csrf_protection_get_html_ret().'" style="color: #ff0000">'.htmlspecialchars($show).'</a></li>';
      }
    }
    echo '</ul>';
  }
  closedir($handle);
}
createDelRestorePageOverview("../data/pages");
?>
<p>
	<i>
		<?php locale('desc_visibility') ?>
	</i>
</p>
</div>

<div id="new">
<h2><?php locale('title_new') ?></h2>
<p>
	<?php locale('desc_new') ?>
</p>
<?php
function createNewPageOverview($ordner) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if(isset($dirs)) {
    echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      echo '<li><a href="new.php?sec='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'&'.SID.csrf_protection_get_html_ret().'">'.htmlspecialchars($show).'</a>';
      createNewPageOverview($dir);
      echo '</li>';
    }
  	echo '</ul>';
  }
  closedir($handle);
}
echo '<ul class="linklist"><li><a href="new.php?sec=root&'.SID.csrf_protection_get_html_ret().'">root</a>';
createNewPageOverview("../data/pages");
echo '</li></ul>';
?>
</div>

<div id="rename">
<h2><?php locale('title_rename') ?></h2>
<?php
function createRenamePageOverview($ordner) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if(isset($dirs)) {
    echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      if ($file != "01,Home") {
        echo '<li><form action="rename.php?'.SID.csrf_protection_get_html_ret().'" method="post" style="display:inline">';
        echo '<label for="'.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'">'.htmlspecialchars($show).'</label>&rarr;<input type="text" id="'.get_short_url(substr($ordner,13).'/'.$file.'/01,Home').'" name="name" /><input type="hidden" name="path" value="'.str_replace('"', '&quot;', $ordner).'" /><input type="hidden" name="file" value="'.str_replace('"', '&quot;', $file).'" /><input type="submit" value="'.locale('button_rename',true).'" /></form>';
      } else {
        echo '<li><span class="inactive">'.$show.'</span>';
      }
      createRenamePageOverview($dir);
      echo '</li>';
    }
    echo '</ul>';
  }
  closedir($handle);
}
createRenamePageOverview("../data/pages");
?>
</div>

<div id="delete">
<h2><?php locale('title_delete') ?></h2>
<?php
function createDeletePageOverview($ordner) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if(isset($dirs)) {
    echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      if ($file != "01,Home") {
        echo '<li><a href="delete.php?file='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).'&'.SID.csrf_protection_get_html_ret().'">'.htmlspecialchars($show).'</a>';
      } else {
        echo '<li><span class="inactive">'.$show.'</span>';
      }
      createDeletePageOverview($dir);
      echo '</li>';
    }
  	echo '</ul>';
  }
  closedir($handle);
}
createDeletePageOverview("../data/pages");
?>
</div>

<div id="sort">
<h2><?php locale('title_sort') ?></h2>
<p>
	<?php locale('desc_sort') ?>
</p>
<?php
function createSortPageOverview($ordner) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if(isset($dirs)) {
    echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      echo '<li><a href="sort1.php?sec='.urlencode(get_short_url(substr($ordner,13).'/'.$file.'/01,Home')).SID.csrf_protection_get_html_ret().'">'.htmlspecialchars($show).'</a>';
      createSortPageOverview($dir);
      echo '</li>';
    }
    echo '</ul>';
  }
  closedir($handle);
}
echo '<ul class="linklist"><li><a href="sort1.php?sec=root&'.SID.csrf_protection_get_html_ret().'">root</a>';
createSortPageOverview("../data/pages");
echo '</li></ul>';
?>
</div>

<div id="attributes">
<h2><?php locale('title_attributes') ?></h2>
<?php
function createAttrPageOverview($ordner) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  if(isset($dirs)) {
    echo '<ul class="linklist">';
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      $shorturl = get_short_url(substr($ordner,13).'/'.$file.'/01,Home');
      echo '<li><a href="attributes.php?file='.urlencode($shorturl).'&'.SID.csrf_protection_get_html_ret().'">'.htmlspecialchars($show).'</a>';
      createAttrPageOverview($dir);
      echo '</li>';
    }
    echo '</ul>';
  }
  closedir($handle);
}
createAttrPageOverview("../data/pages");
?>
</div>

	</body>
</html>
